@@ -2,6 +2,7 @@ import datetime
 import re
 
 from django.db import models
+from django.utils.translation import ugettext
 from django.utils.translation import ugettext_lazy as _
 from django.conf import settings
 from django.core.urlresolvers import reverse
@@ -14,7 +15,7 @@ from utils.fields import FiberMarkupField, FiberHTMLField
 
 from fiber import editor
 
-from app_settings import IMAGES_DIR, FILES_DIR
+from app_settings import IMAGES_DIR, FILES_DIR, METADATA_PAGE_SCHEMA, METADATA_CONTENT_SCHEMA
 
 from utils.urls import get_named_url_from_quoted_url, is_quoted_url
 from utils.json import JSONField
@@ -104,7 +105,7 @@ class ContentItem(models.Model):
     content_html = FiberHTMLField(verbose_name=_('Content'))
     protected = models.BooleanField(_('protected'), default=False)
 
-    metadata = JSONField(_('metadata'), blank=True, null=True)
+    metadata = JSONField(_('metadata'), blank=True, null=True, schema=METADATA_CONTENT_SCHEMA, prefill_from='fiber.models.ContentItem')
 
     objects = ContentItemManager()
 
@@ -115,7 +116,7 @@ class ContentItem(models.Model):
             contents = ' '.join(strip_tags(self.content_html).strip().split())
             if len(contents) > 50:
                 contents = contents[:50] + '...'
-            return contents or _('[ EMPTY ]')
+            return contents or ugettext('[ EMPTY ]') # TODO: find out why ugettext_lazy doesn't work here
 
     @classmethod
     def get_add_url(cls):
@@ -158,7 +159,7 @@ class Page(MPTTModel):
 
     content_items = models.ManyToManyField(ContentItem, through='PageContentItem', verbose_name=_('content items'))
 
-    metadata = JSONField(blank=True, null=True)
+    metadata = JSONField(blank=True, null=True, schema=METADATA_PAGE_SCHEMA, prefill_from='fiber.models.Page')
 
     objects = PageManager()
 
