@@ -2,6 +2,8 @@ var fiber_jQuery = $.noConflict(true);
 
 // fiber namespace
 var Fiber = {};
+Fiber.enhance_combobox = function(select) {};
+Fiber.enhance_jsontextarea = function(select) {};
 Fiber.enhance_textarea = function(textarea) {};
 Fiber.remove_textarea = function(textarea) {};
 
@@ -268,6 +270,11 @@ var LoginFormDialog = AdminFormDialog.extend({
 					this.after_action_success();
 				} else {
 					var errornote = this.admin_form.form.find('p.errornote');
+					// check if errornote already exists
+					if (errornote.length === 0) {
+						errornote = $('<p class="errornote"></p>');
+						this.admin_form.form.prepend(errornote);
+					}
 					errornote.text(data.message);
 				}
 			}
@@ -299,23 +306,22 @@ var LoginForm = AdminForm.extend({
 
 	// get the form element from the HTML that is returned by the XHR
 	get_form_from_HTML: function(html) {
-		var errornote = $(document.createElement('p')).addClass('errornote');
-		var forms = $(document.createElement('div')).html(this.strip_HTML(html)).find('form');
+		var forms = $(document.createElement('div')).html(this.strip_HTML(html)).find('#content-main form[id$=-form]');
+
 		if (forms.length == 1) {
 			this.form = $(forms[0]);
-			this.form.prepend(errornote);
 		}
 	},
 
 	set_interaction: function() {
 		this.form.find('#id_username').focus();
 		this.form.find('#id_password').keypress(function (e) {
-				if ((e.which && e.which == 13) || (e.keyCode && e.keyCode == 13)) {
-					$('#login_button').click();
-					return false;
-				} else {
-					return true;
-				}
+			if ((e.which && e.which == 13) || (e.keyCode && e.keyCode == 13)) {
+				$('#login_button').click();
+				return false;
+			} else {
+				return true;
+			}
 		});
 	},
 
@@ -386,6 +392,18 @@ function enhance_textareas(container) {
 	});
 }
 
+function enhance_comboboxes(container) {
+	container.find('select.fiber-combobox').each(function() {
+		Fiber.enhance_combobox(this);
+	});
+}
+
+function enhance_jsontextareas(container) {
+	container.find('textarea.fiber-jsonwidget').each(function() {
+		Fiber.enhance_jsontextarea(this);
+	});
+}
+
 var ChangeForm = AdminForm.extend({
 
 	set_styling: function() {
@@ -400,6 +418,8 @@ var ChangeForm = AdminForm.extend({
 
 	set_interaction: function() {
 		enhance_textareas(this.form);
+		enhance_comboboxes(this.form);
+		enhance_jsontextareas(this.form);
 	},
 
 	destroy: function() {
@@ -1613,6 +1633,13 @@ var adminPage = {
 
 	init_backend: function() {
 		enhance_textareas($(document.body));
+		enhance_comboboxes($(document.body));
+		enhance_jsontextareas($(document.body));
+		var backend_toolbar = $('<div id="fiber-backend-toolbar"></div>');
+		var frontend_button = $('<p class="frontend"></p>').appendTo(backend_toolbar);
+		var link = $(document.createElement('a')).text(gettext('Frontend')).attr('href', '/').attr('title', gettext('Frontend')).appendTo(frontend_button);
+		$('<span class="icon"></span>').prependTo(link);
+		backend_toolbar.prependTo($('body'));
 	},
 
 	init: function(body_fiber_data) {
